<?php

namespace Teknisa\CNC\Factories;

use Doctrine\ORM\EntityManager;

class Cnc00200AdquirentesFactory {
    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }
    
    public function saveTecnologiaAdq($params) {
        $sql = "UPDATE TECNOLOGIAADQ
                  SET NRTIPOTECNOLOG = :NRTIPOTECNOLOG,
                    VRALUGUEL = :VRALUGUEL
                WHERE NRORG = :NRORG
                 AND NRTECNOLOGADQ = :NRTECNOLOGADQ
                 AND NRADQUIRENTE = :NRADQUIRENTE";
                  
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function insertTecnologiaAdq ($params) {
        $sql = "INSERT INTO TECNOLOGIAADQ
                  (NRADQUIRENTE, NRTECNOLOGADQ, NRTIPOTECNOLOG, VRALUGUEL, NRORG, IDATIVO, DTULTATU, NRORGULTATU, CDOPERULTATU)
                VALUES
                  (:NRADQUIRENTE, :NRTECNOLOGADQ, :NRTIPOTECNOLOG, :VRALUGUEL, :NRORG, :IDATIVO, :DTULTATU, :NRORGULTATU, :CDOPERULTATU)";
                  
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function getTecnologiaAdq($params){
        $sql = "SELECT TA.NRADQUIRENTE, TA.NRTECNOLOGADQ, TA.NRTIPOTECNOLOG, TA.VRALUGUEL, T.NMTIPOTECNOLOG 
                 FROM TECNOLOGIAADQ TA
                  JOIN TIPOTECNOLOGIA T
                   ON TA.NRTIPOTECNOLOG = T.NRTIPOTECNOLOG
                  WHERE TA.NRORG = :NRORG
                   AND TA.NRADQUIRENTE = :NRADQUIRENTE
                   AND TA.NRESTABELEC IS NULL";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function deleteTecnologiaAdq($params) {
        $sql = "DELETE FROM TECNOLOGIAADQ
                WHERE NRORG = :NRORG
                  AND IDATIVO = :IDATIVO
                  AND NRTIPOTECNOLOG = :NRTIPOTECNOLOG
                  AND NRADQUIRENTE = :NRADQUIRENTE";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function checkExistsTecAdq ($params) {
        $sql = "SELECT COUNT(*) NR
                  FROM TECNOLOGIAADQ TA
                   JOIN TIPOTECNOLOGIA T
                    ON TA.NRTIPOTECNOLOG = T.NRTIPOTECNOLOG
                   WHERE T.NRTIPOTECNOLOG = :NRTIPOTECNOLOG
                    AND TA.NRADQUIRENTE = :NRADQUIRENTE
                    AND NRTECNOLOGADQ <> :NRTECNOLOGADQ
                    AND NRESTABELEC IS NULL";        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function saveTecnologiaAdqEst($params) {
        $sql = "UPDATE TECNOLOGIAADQ
                  SET NRESTABELEC = :NRESTABELEC,
                    VRALUGUEL = :VRALUGUEL
                WHERE NRORG = :NRORG
                 AND NRTECNOLOGADQ = :NRTECNOLOGADQ
                 AND NRTIPOTECNOLOG = :NRTIPOTECNOLOG
                 AND NRADQUIRENTE = :NRADQUIRENTE";
                  
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function insertTecnologiaAdqEst($params) {
        $sql = "INSERT INTO TECNOLOGIAADQ
                  (NRESTABELEC, NRADQUIRENTE, NRTECNOLOGADQ, NRTIPOTECNOLOG, VRALUGUEL, NRORG, IDATIVO, DTULTATU, NRORGULTATU, CDOPERULTATU)
                VALUES
                  (:NRESTABELEC, :NRADQUIRENTE, :NRTECNOLOGADQ, :NRTIPOTECNOLOG, :VRALUGUEL, :NRORG, :IDATIVO, :DTULTATU, :NRORGULTATU, :CDOPERULTATU)";
                  
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function getTecnologiaAdqEst($params){
        $sql = "SELECT TA.NRTIPOTECNOLOG, TA.NRTECNOLOGADQ, T.NMTIPOTECNOLOG, TA.NRADQUIRENTE, E.NRESTABELEC, E.CDESTABELEC|| ' - ' || E.NMESTABELEC LABELESTABELEC, TA.VRALUGUEL
                   FROM TECNOLOGIAADQ TA
                    JOIN ESTABELECIMENTO E
                     ON E.NRESTABELEC = TA.NRESTABELEC
                    JOIN TIPOTECNOLOGIA T
                     ON T.NRTIPOTECNOLOG = TA.NRTIPOTECNOLOG
                    WHERE TA.NRORG = :NRORG
                     AND TA.NRADQUIRENTE = :NRADQUIRENTE
                     AND TA.NRTIPOTECNOLOG = :NRTIPOTECNOLOG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function deleteTecnologiaAdqEst($params) {
        $sql = "DELETE FROM TECNOLOGIAADQ
                WHERE NRORG = :NRORG
                  AND IDATIVO = :IDATIVO
                  AND NRTECNOLOGADQ = :NRTECNOLOGADQ
                  AND NRADQUIRENTE  = :NRADQUIRENTE
                  AND NRESTABELEC  = :NRESTABELEC";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function checkExistsTecAdqEst($params) {
        $sql = "SELECT COUNT(*) NR
                  FROM TECNOLOGIAADQ TA
                   JOIN TIPOTECNOLOGIA T
                    ON TA.NRTIPOTECNOLOG = T.NRTIPOTECNOLOG
                   WHERE T.NRTIPOTECNOLOG = :NRTIPOTECNOLOG
                    AND TA.NRADQUIRENTE = :NRADQUIRENTE
                    AND NRESTABELEC = :NRESTABELEC
                    AND NRTECNOLOGADQ <> :NRTECNOLOGADQ";        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getAdquirentesSeries ($params) {
        $sql = "SELECT F.CDINSCESTA, F.CDINSCMUNI, F.CDSERIE, F.CDEMPRESA
                FROM FILIAL F LEFT JOIN ESTABELECIMENTO E
                  ON F.NRINSJURFILI = E.NRCNPJESTABELEC
                WHERE F.NRORG = :NRORG
                  AND E.NRESTABELEC = :NRESTABELEC";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getContcorrEmpresa ($params) {
        $sql = "SELECT CDCONTCORR, CDBANCO
                FROM CONTCORR
                WHERE NRORG = :NRORG
                  AND CDEMPRESA = :CDEMPRESA";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getInscValues ($params) {
        $sql = "SELECT F.CDINSCMUNI, F.CDINSCESTA, F.CDEMPRESA
                FROM ESTABELECIMENTO E, FILIAL F, EMPRESA P
                WHERE E.NRORG = :NRORG
                  AND E.NRESTABELEC = :NRESTABELEC
                  AND F.CDFILIAL = E.CDFILIAL
                  AND F.CDEMPRESA = P.CDEMPRESA";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function validateEstabelec ($params) {
        $sql = "SELECT COUNT(*) COUNT
                FROM PARAMFINESTADQ
                WHERE NRORG = :NRORG
                  AND NRESTABELEC = :NRESTABELEC
                  AND NRADQUIRENTE = :NRADQUIRENTE";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll()[0];
    }

    public function filterAdqFinacRow ($params) {
        $sql = "SELECT P.NRPARAMFINESTADQ, P.NRESTABELEC , E.NMESTABELEC , P.NRADQUIRENTE, 
                  P.CDEMPRESA, EM.NMEMPRESA, P.CDINSCESTA, P.CDINSCMUNI, P.CDSERIE, 
                  S.DSSERIE, P.CDREDUCONT, CONT.CDCONTCORR, 
                  B.NMBANCO, CONT.CDAGENCIA, CONT.CDBANCO, P.CDTPCTRECEB, 
                  TCR.DSTPCTRECEB, P.CDAJUCTREC, TAR.DSAJUCTREC, 
                  P.CDTPDEBIBANC, TDB.DSTPDEBIBANC, P.CDTPDBDEBGER, TD.DSTPDEBIBANC DSTPDBDEBGER, P.CDCLIENTE, 
                  C.NMRAZSOCCLIE, P.NRORG, P.CDTIPOOPER, P.IDENTRSAIDOP, TOA.NMTIPOOPER,
                  B.CDPICTCONT, B.CDPICTAGEN, P.CDTPCREDBANC
                FROM PARAMFINESTADQ P LEFT JOIN CONTCORR CONT
                    ON P.CDREDUCONT = CONT.CDREDUCONT
                  LEFT JOIN TIPOCTRECEBER TCR
                    ON P.CDTPCTRECEB = TCR.CDTPCTRECEB
                  LEFT JOIN TIPOAJRECEBER TAR
                    ON P.CDAJUCTREC = TAR.CDAJUCTREC
                  LEFT JOIN TPDEBIBANC TDB
                    ON P.CDTPDEBIBANC = TDB.CDTPDEBIBANC
                  LEFT JOIN TPDEBIBANC TD
                    ON P.CDTPDBDEBGER = TD.CDTPDEBIBANC
                  LEFT JOIN TIPOOPERAC TOA
                    ON P.CDTIPOOPER = TOA.CDTIPOOPER
                    AND P.IDENTRSAIDOP = TOA.IDENTRSAIDOP
                  LEFT JOIN SERIENF S
                    ON P.CDSERIE = S.CDSERIE
                    AND P.CDINSCMUNI = S.CDINSCMUNI
                    AND P.CDINSCESTA = S.CDINSCESTA
                  LEFT JOIN CLIENTE C
                    ON P.CDCLIENTE = C.CDCLIENTE
                  LEFT JOIN BANCO B
                    ON CONT.CDBANCO = B.CDBANCO
                  LEFT JOIN TPCREDBANC TCB
                    ON TCB.CDTPCREDBANC = P.CDTPCREDBANC, ESTABELECIMENTO E, EMPRESA EM
                WHERE P.NRORG = :NRORG
                  AND P.NRADQUIRENTE = :NRADQUIRENTE
                   AND P.NRESTABELEC = :NRESTABELEC
                  AND P.NRESTABELEC = E.NRESTABELEC
                  AND P.CDEMPRESA = EM.CDEMPRESA
                ORDER BY P.NRESTABELEC";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function insertLogAdqFinac ($params) {
        $sql = "INSERT INTO LOGFINESTADQ
                  (NRLOGFINESTADQ, NRADQUIRENTE, NRESTABELEC, DTOPERACAO, CDOPERADOR, IDTIPO, DSINFANTIGA, DSINFNOVA)
                VALUES
                  (:NRLOGFINESTADQ, :NRADQUIRENTE, :NRESTABELEC, TO_CHAR(SYSDATE, 'DD/MM/YYYY HH24:MI:SS'), :CDOPERADOR, :IDTIPO, :DSINFANTIGA, :DSINFNOVA)";                  
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
}